@@ -2,13 +2,13 @@
 Code based on solution https://gist.github.com/joshbode/569627ced3076931b02f
 """
 
-from typing import Any, IO
-import json
 import logging
 import os
+from typing import IO, Any
+
 import yaml
 
-from scanapi.errors import EmptyConfigFileError, FileFormatNotSupportedError
+from scanapi.errors import EmptyConfigFileError
 
 logger = logging.getLogger(__name__)
 
@@ -32,23 +32,13 @@ def construct_include(loader: Loader, node: yaml.Node) -> Any:
 
     relative_path = os.path.join(loader._root, loader.construct_scalar(node))
     full_path = os.path.abspath(relative_path)
-    extension = os.path.splitext(full_path)[1].lstrip(".")
 
     with open(full_path, "r") as f:
-        if extension in ("yaml", "yml"):
-            return yaml.load(f, Loader)
-        elif extension in ("json",):
-            return json.load(f)
-        else:
-            raise FileFormatNotSupportedError(f".{extension}", relative_path)
+        return yaml.load(f, Loader)
 
 
 def load_config_file(file_path):
-    extension = os.path.splitext(file_path)[-1]
-
-    if extension not in (".yaml", ".yml", ".json"):
-        raise FileFormatNotSupportedError(extension, file_path)
-
+    """ Loads configuration file. If non-empty file exists reads data and returns it """
     with open(file_path, "r") as stream:
         logger.info(f"Loading file {file_path}")
         data = yaml.load(stream, Loader)
