@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 import datetime
 import logging
+from os.path import abspath
 
 from scanapi.session import session
 from scanapi.settings import settings
@@ -16,8 +17,7 @@ class Reporter:
         self.template = template
 
     def write(self, results):
-        """ Part of the Reporter instance that is responsible for writing scanapi-report.html.
-        """
+        """Part of the Reporter instance that is responsible for writing scanapi-report.html."""
         logger.info("Writing documentation")
 
         template_path = self.template if self.template else "report.html"
@@ -30,11 +30,11 @@ class Reporter:
             doc.write(content)
 
         logger.info("\nThe documentation was generated successfully.")
-        logger.info(f"It is available at {self.output_path}")
+        logger.info(f"It is available at {abspath(self.output_path)}")
 
     @staticmethod
     def _build_context(results):
-        """ Private method of Reporter returns dict containing keys datetime,
+        """Private method of Reporter returns dict containing keys datetime,
         project_name, results and session and their corresponding values.
         """
         return {
