@@ -1,22 +1,24 @@
 import logging
-import requests
+import time
 
 from scanapi.errors import HTTPMethodNotAllowedError
-from scanapi.evaluators.spec_evaluator import SpecEvaluator
+from scanapi.evaluators.spec_evaluator import SpecEvaluator  # noqa: F401
+from scanapi.hide_utils import hide_sensitive_info
 from scanapi.test_status import TestStatus
 from scanapi.tree.testing_node import TestingNode
 from scanapi.tree.tree_keys import (
     BODY_KEY,
+    DELAY_KEY,
     HEADERS_KEY,
     METHOD_KEY,
     NAME_KEY,
     PARAMS_KEY,
     PATH_KEY,
+    RETRY_KEY,
     TESTS_KEY,
     VARS_KEY,
 )
-from scanapi.utils import join_urls, validate_keys
-from scanapi.hide_utils import hide_sensitive_info
+from scanapi.utils import join_urls, session_with_retry, validate_keys
 
 logger = logging.getLogger(__name__)
 
@@ -32,8 +34,18 @@ class RequestNode:
         PATH_KEY,
         TESTS_KEY,
         VARS_KEY,
+        DELAY_KEY,
+        RETRY_KEY,
+    )
+    ALLOWED_HTTP_METHODS = (
+        "GET",
+        "POST",
+        "PUT",
+        "PATCH",
+        "DELETE",
+        "HEAD",
+        "OPTIONS",
     )
-    ALLOWED_HTTP_METHODS = ("GET", "POST", "PUT", "PATCH", "DELETE")
     REQUIRED_KEYS = (NAME_KEY,)
 
     def __init__(self, spec, endpoint):
@@ -81,17 +93,30 @@ class RequestNode:
 
         return self.endpoint.vars.evaluate({**endpoint_params, **params})
 
+    @property
+    def delay(self):
+        delay = self.spec.get(DELAY_KEY, 0)
+        return delay or self.endpoint.delay
+
     @property
     def body(self):
-        body = self.spec.get(BODY_KEY, {})
+        body = self.spec.get(BODY_KEY)
 
         return self.endpoint.vars.evaluate(body)
 
     @property
     def tests(self):
-        return (TestingNode(spec, self) for spec in self.spec.get("tests", []))
+        return (
+            TestingNode(spec, self) for spec in self.spec.get(TESTS_KEY, [])
+        )
+
+    @property
+    def retry(self):
+        return self.spec.get(RETRY_KEY)
 
     def run(self):
+        time.sleep(self.delay / 1000)
+
         method = self.http_method
         url = self.full_url_path
         logger.info("Making request %s %s", method, url)
@@ -100,7 +125,8 @@ class RequestNode:
             self.spec.get(VARS_KEY, {}), preevaluate=False,
         )
 
-        response = requests.request(
+        session = session_with_retry(self.retry)
+        response = session.request(
             method,
             url,
             headers=self.headers,
