@@ -10,3 +10,6 @@ REQUESTS_KEY = "requests"
 ROOT_SCOPE = "root"
 TESTS_KEY = "tests"
 VARS_KEY = "vars"
+DELAY_KEY = "delay"
+RETRY_KEY = "retry"
+MAX_RETRIES_KEY = "max_retries"
